<?php
/**
 * SocialSharePrivacy class file.
 *
 * @author Markus Schanz <coksnuss@googlemail.com>
 * @link http://www.sms-bude.de
 * @license MIT
 */

/**
 * SocialSharePrivacy embeds a "I Like"-Bar into a page, which needs to be activated by the user.
 *
 * Based on the jQuery Plugin socialshareprivacy (v1.4) by heise.de.
 * http://www.heise.de/extras/socialshareprivacy/
 *
 * @author Markus Schanz <coksnuss@googlemail.com>
 * @version 1.0
 * @package extensions.widgets
 * @since 1.0
 */
class SocialSharePrivacy extends CWidget
{
	/**
	 * @var integer The position at which the required .js file will be included. This can be one of the
	 * CClientScript::POS_* constants. Defaults to CClientScript::POS_END.
	 */
	public $position = CClientScript::POS_END;
	/**
	 * @var array The options, passed to the plugin. Please refer to one of the following sources:
	 * Check the content of file assets/jquery.socialshareprivacy.js (Options starting at line 85)
	 * Offical Documentation: http://www.heise.de/extras/socialshareprivacy/#options
	 */
	public $options = array();
	/**
	 * @var array The html options passed to the surrounding div container.
	 */
	public $htmlOptions = array();

	/**
	 * Register jQuery library and publish required js/css/png files.
	 */
	public function init()
	{
		$assets = Yii::app()->assetManager->publish(__DIR__ . DIRECTORY_SEPARATOR . 'assets');

		if(isset($this->htmlOptions['id']))
			$this->setId($this->htmlOptions['id']);

		if(!isset($this->options['services']['facebook']['dummy_img']))
			$this->options['services']['facebook']['dummy_img'] = $assets . '/images/dummy_facebook.png';
		if(!isset($this->options['services']['twitter']['dummy_img']))
			$this->options['services']['twitter']['dummy_img'] = $assets . '/images/dummy_twitter.png';
		if(!isset($this->options['services']['gplus']['dummy_img']))
			$this->options['services']['gplus']['dummy_img'] = $assets . '/images/dummy_gplus.png';
		if(!isset($this->options['css_path']))
			$this->options['css_path'] = $assets . '/socialshareprivacy.css';

		$script = "jQuery('#{$this->id}').socialSharePrivacy(" . CJSON::encode($this->options) . ");";

		Yii::app()->clientScript
			->registerCoreScript('jquery')
			->registerScriptFile($assets . '/jquery.socialshareprivacy' . (YII_DEBUG ? '' : '.min') . '.js', $this->position)
			->registerScript(__CLASS__ . '#' . $this->id, $script, CClientScript::POS_READY);
	}

	/**
	 * Output the surrounding div container.
	 */
	public function run()
	{
		echo CHtml::openTag('div', array_merge($this->htmlOptions, array('id' => $this->id))) . '</div>';
	}
}
?>
